## 24.3 (2024-03-10)

- Add missing parser/serializer shortcuts
- General project maintenance

## 23.8 (2023-08-12)

- Removed python 3.6 and 3.7 support
- Added official support for 3.11 and 3.12
- Set xsdata minimum version v23.5

## 21.11 (2021-11-02)

- Fixed dataclass.unsafe_hash mapping to attrs.hash property
  [#7](https://github.com/tefra/xsdata-attrs/issues/7)

## 21.8 (2021-08-03)

- Initial Release
